Learn R Programming

pscl (version 1.04.4)

iraqVote: U.S. Senate vote on the use of force against Iraq, 2002.

Description

On October 11, 2002, the United States Senate voted 77-23 to authorize the use of military force against Iraq. This data set lists the Ayes and Nays for each Senator and some covariates.

Usage

data(iraqVote)

Arguments

source

Keith Poole, 107th Senate Roll Call Data. ftp://voteview.com/sen107kh.ord The Iraq vote is vote number 617.

David Leip's Atlas of U.S. Presidential Elections. http://uselectionatlas.org

Details

The only Republican to vote against the resolution was Lincoln Chafee (Rhode Island); Democrats split 29-22 in favor of the resolution.

References

Jackman, Simon. 2009. Bayesian Analysis for the Social Sciences. Wiley: Chichester. Example 8.3.

Examples

Run this code
data(iraqVote)
## probit model
glm1 <- glm(y ~ gorevote + rep,
            data=iraqVote,
            family=binomial(link=probit))
require(MCMCpack)
albertChib <- MCMCprobit(y ~ gorevote + rep,
                         data=iraqVote,
                         burnin=0,
                         B0=1e-3,
                         mcmc=1e4,
                         verbose=0)

Run the code above in your browser using DataLab